@@ -27,7 +27,7 @@
 //!   `'string'`, `"string"`, `'''string'''`, or `"""string"""`.
 //!
 //! * `WritableElement` and `ReadableElement` are currently implemented only
-//!   for fixed-size integers and floating point numbers.
+//!   for fixed-size integers, floating point numbers, and `bool`.
 //!
 //! The plan is to add support for more element types (including custom
 //! user-defined structs) in the future.
@@ -47,7 +47,8 @@ mod npy;
 #[cfg(feature = "npz")]
 mod npz;
 
-pub use npy::{ReadNpyError, ReadNpyExt, ReadableElement, WritableElement, WriteNpyError,
-              WriteNpyExt};
+pub use crate::npy::{
+    ReadNpyError, ReadNpyExt, ReadableElement, WritableElement, WriteNpyError, WriteNpyExt,
+};
 #[cfg(feature = "npz")]
-pub use npz::{NpzReader, NpzWriter, ReadNpzError, WriteNpzError};
+pub use crate::npz::{NpzReader, NpzWriter, ReadNpzError, WriteNpzError};
